pub type EventStream = Pin<Box<dyn Stream<Item = Result<DockerEvent, EventsError>> + Send>>;Expand description
Shared type alias for the complex event stream return type.
Aliased Type
pub struct EventStream { /* private fields */ }pub type EventStream = Pin<Box<dyn Stream<Item = Result<DockerEvent, EventsError>> + Send>>;Shared type alias for the complex event stream return type.
pub struct EventStream { /* private fields */ }